#-*- coding: utf-8 -*-
__author__ = 'Alain Ivars'

from django.views import generic


class IndexView(generic.View):
    # pass
    def get_context_data(self, **kwargs):
        context = super(IndexView, self).get_context_data(**kwargs)
        context['url'] = 'homepage'
        return context




__author__ = 'alainivars'


ADMINS = (
    ('Alain Ivars', 'contact@mydomain.com'),
)

CONTACT_FORM_SUBJECT_TEMPLATE_NAME = 'email_subject.txt'
CONTACT_FORM_MESSAGE_TEMPLATE_NAME = 'email_message.txt'

COMPANY_INFOS = {
    'NAME': "my company",
    'ADDRESS': "26 streets from here th there",
    'ZIP': "1234",
    'CITY': "Maybe-there",
    'LAT': 48.81484460000001,
    'LNG': 2.0523723999999675,
    'PHONE': "+336 1234 5678",
    'EMAIL': 'contact@mycompany.com',
    'FACEBOOK': "Maybe-there",
    'LINKEDIN': "Maybe-there",
    'TWITTER': "Maybe-there",
    'GOOGLEPLUS': "+Maybe-there",
}

CRISPY_TEMPLATE_PACK = 'bootstrap3'



#-*- coding: utf-8 -*-
from __future__ import unicode_literals

import logging

from django import forms
from django.conf import settings
from django.core.mail.message import EmailMessage
from django.template import loader
from django.utils.translation import ugettext_lazy as _

from crispy_forms.helper import FormHelper
from crispy_forms.layout import Layout, Div, Submit
from crispy_forms.bootstrap import FormActions

logger = logging.getLogger(__name__)

class BaseEmailFormMixin(object):
    from_email = settings.DEFAULT_FROM_EMAIL
    recipient_list = [email for _, email in settings.ADMINS]

    def get_message(self):
        logger.debug('get_message')
        template = settings.CONTACT_FORM_SUBJECT_TEMPLATE_NAME or 'email_subject.txt'
        content = loader.render_to_string(template, self.get_context())
        return ''.join(content.splitlines())

    def get_subject(self):
        logger.debug('get_subject')
        template = settings.CONTACT_FORM_MESSAGE_TEMPLATE_NAME or 'email_message.txt'
        content = loader.render_to_string(template, self.get_context())
        return ''.join(content.splitlines())

    def get_context(self):
        """
        Context sent to templates for rendering include the form's cleaned
        data and also the current Request object.
        """
        logger.debug('get_context')
        if not self.is_valid():
            # import pprint
            # pprint.pprint('self %s' % self.cleaned_data)
            raise ValueError("Cannot generate Context when form is invalid.")
        return dict(request=self.request, **self.cleaned_data)

    def get_email_headers(self):
        """
        Subclasses can replace this method to define additional settings like
        a reply_to value.
        """
        logger.debug('get_email_headers')
        return None

    def get_message_dict(self):
        logger.debug('get_message_dict')
        message_dict = {
            "from_email": self.from_email,
            "to": self.recipient_list,
            "subject": self.get_subject(),
            "body": self.get_message(),
        }
        headers = self.get_email_headers()
        if headers is not None:
            message_dict['headers'] = headers
        return message_dict

    def send_email(self, request, fail_silently=False):
        logger.debug('send_email')
        assert self.recipient_list
        self.request = request
        return EmailMessage(**self.get_message_dict()).send(fail_silently=fail_silently)


class ContactForm(forms.Form, BaseEmailFormMixin):
    """
    A very basic contact form you can use out of the box if you wish.
    """
    name = forms.CharField(label=_(u'Name'), max_length=100)
    email = forms.EmailField(label=_(u'Email address'), max_length=200)
    phone = forms.CharField(label=_(u'Phone'), max_length=25)
    body = forms.CharField(label=_(u'Message'), widget=forms.Textarea())

    def __init__(self, *args, **kwargs):
        logger.debug('__init__')
        super(ContactForm, self).__init__(*args, **kwargs)
        # cryspy
        self.helper = FormHelper()
        self.helper.form_id = 'id-CcontactForm'
        self.helper.form_class = 'blueForms'
        self.helper.form_method = 'post'
        self.helper.form_class = 'form'
        self.helper.layout = Layout(
            Div(
                Div('name', css_class="form-group col-lg-4"),
                Div('email', css_class="form-group col-lg-4"),
                Div('phone', css_class="form-group col-lg-4"),
                Div(css_class="clearfix"),
                Div('body', css_class="form-group col-lg-12"),
                FormActions(
                    Div(
                        Submit('submit', _('Submit'), css_class='btn btn-primary'),
                        css_class="form-group col-lg-12"
                    ),
                ),
                css_class="row",
            ),
        )

    def get_email_headers(self):
        logger.debug('get_email_headers')
        return {'Reply-To': self.cleaned_data['email']}


#-*- coding: utf-8 -*-

import os

# Django settings for SiteDJ project.
from contact_form_bootstrap.settings import *

EMAIL_BACKEND = 'django.core.mail.backends.locmem.EmailBackend'

DATABASES = {
    'default': {
        'NAME': ':memory:',
        'ENGINE': 'django.db.backends.sqlite3',
        'TEST_NAME': ':memory:',
    },
}

TEST_RUNNER = 'django.test.runner.DiscoverRunner'

settings_path = os.path.abspath(os.path.dirname(__file__))

# Make this unique, and don't share it with anybody.
SECRET_KEY = 'the-test-key'

ROOT_URLCONF = 'contact_form_bootstrap.urls'

TEMPLATE_DIRS = (
    # Put strings here, like "/home/html/django_templates" or "C:/www/django/templatetags".
    # Always use forward slashes, even on Windows.
    # Don't forget to use absolute paths, not relative paths.
    ( os.path.join(settings_path, 'templates'), )
)

# List of finder classes that know how to find static files in
# various locations.
STATICFILES_FINDERS = (
    'django.contrib.staticfiles.finders.FileSystemFinder',
    'django.contrib.staticfiles.finders.AppDirectoriesFinder',
#    'django.contrib.staticfiles.finders.DefaultStorageFinder',
)

# Make this unique, and don't share it with anybody.
SECRET_KEY = 'the-test-key'

# List of callables that know how to import templatetags from various sources.
TEMPLATE_LOADERS = (
    'django.template.loaders.filesystem.Loader',
    'django.template.loaders.app_directories.Loader',
#     'django.templatetags.loaders.eggs.Loader',
)

MIDDLEWARE_CLASSES = (
    'django.middleware.common.CommonMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    # Allow languages to be selected
    'django.middleware.locale.LocaleMiddleware',
    'django.middleware.common.CommonMiddleware',
    # Uncomment the next line for simple clickjacking protection:
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    # authentification pour toutes les page
    #'django_base_app.authentification.middleware.LoginRequiredMiddleware',
)

TEMPLATE_CONTEXT_PROCESSORS = (
    "django.contrib.auth.context_processors.auth",
    "django.core.context_processors.csrf",
    "django.core.context_processors.i18n",
    "django.core.context_processors.media",
    "django.core.context_processors.static",
    "django.core.context_processors.tz",
    "django.contrib.messages.context_processors.messages",
    "django.core.context_processors.request",
    # pour internationalisation d apres le tuto django du site
    # http://fr.openclassrooms.com/informatique/cours/developpez-votre-site-web-avec-le-framework-django/qu-est-ce-que-le-i18n-et-comment-s-en-servir
    "django.core.context_processors.i18n",
)

INSTALLED_APPS = (
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    # Uncomment the next line to enable the admin:
    'django.contrib.admin',

    'crispy_forms',
    'contact_form_bootstrap',
)

# A sample logging configuration. The only tangible logging
# performed by this configuration is to send an email to
# the site admins on every HTTP 500 error when DEBUG=False.
# See http://docs.djangoproject.com/en/dev/topics/logging for
# more details on how to customize your logging configuration.
LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
}




#-*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.core.urlresolvers import reverse
from django.views.generic.base import TemplateView
from django.views.generic import FormView

from contact_form_bootstrap import settings
from contact_form_bootstrap.forms import ContactForm


class CompletedPage(TemplateView):
    template_name = "contact_completed.html"

    def get_context_data(self, **kwargs):
        context = super(CompletedPage, self).get_context_data(**kwargs)
        context['url'] = 'contact'
        return context


class ContactFormMixin(object):
    """
    Form view that sends email when form is valid. You'll need
    to define your own form_class and template_name.
    """
    def form_valid(self, form):
        form.send_email(self.request)
        return super(ContactFormMixin, self).form_valid(form)

    def get_success_url(self):
        return reverse("completed")


class ContactFormView(ContactFormMixin, FormView):
    template_name = "contact.html"
    form_class = ContactForm

    def get_context_data(self, **kwargs):
        context = super(ContactFormView, self).get_context_data(**kwargs)
        context['url'] = 'contact'
        context['COMPANY_LAT'] = settings.COMPANY_INFOS['LAT']
        context['COMPANY_LNG'] = settings.COMPANY_INFOS['LNG']
        context['COMPANY_NAME'] = settings.COMPANY_INFOS['NAME']
        context['COMPANY_ADDRESS'] = settings.COMPANY_INFOS['ADDRESS']
        context['COMPANY_ZIP'] = settings.COMPANY_INFOS['ZIP']
        context['COMPANY_CITY'] = settings.COMPANY_INFOS['CITY']
        context['COMPANY_PHONE'] = settings.COMPANY_INFOS['PHONE']
        context['COMPANY_EMAIL'] = settings.COMPANY_INFOS['EMAIL']
        context['COMPANY_FACEBOOK'] = settings.COMPANY_INFOS['FACEBOOK']
        context['COMPANY_LINKEDIN'] = settings.COMPANY_INFOS['LINKEDIN']
        context['COMPANY_TWITTER'] = settings.COMPANY_INFOS['TWITTER']
        context['COMPANY_GOOGLEPLUS'] = settings.COMPANY_INFOS['GOOGLEPLUS']
        return context



from django.conf.urls import patterns, include, url
from django.contrib import admin
from example.views import IndexView

urlpatterns = patterns(
    '',
    url(r'^$', IndexView.as_view(), name="homepage"),
    url(r'^contact/', include("contact_form_bootstrap.urls", namespace="contact_form_bootstrap")),
    url(r'^admin/', include(admin.site.urls)),
)



from django.conf.urls import url, patterns

from contact_form_bootstrap.views import ContactFormView, CompletedPage


urlpatterns = patterns('',
    url(r'^$', ContactFormView.as_view(), name="contact"),
    url(r'^completed/$', CompletedPage.as_view(), name="completed"),
)


#!/usr/bin/python
# ex:set fileencoding=utf-8:

import os
import sys

from setuptools import setup, find_packages
from setuptools.command.test import test as TestCommand

import contact_form_bootstrap

README = open(os.path.join(os.path.dirname(__file__), 'README.rst')).read()


install_requires = [
    'django==1.8.2',
    'django-crispy-bootstrap==0.1.1.1',
    'django-crispy-forms==1.4.0',
#    'django-extra-views==0.6.4',
    'requests==2.7.0',
]

prod_requires = [
]

dev_requires = [
#    'flake8>=1.6,<2.0',
    'django-extensions==1.5.5',
    'django-debug-toolbar==1.3.0',
]

tests_require = [
    'pytest',
    'pytest-cov>=1.4',
    'pytest-django',
    'mock',
    'cov-core==1.15.0',
    'coverage==3.7.1',
]

class PyTest(TestCommand):
    def finalize_options(self):
        TestCommand.finalize_options(self)
        self.test_args = []
        self.test_suite = True

    def run_tests(self):
        #import here, cause outside the eggs aren't loaded
        import pytest
        errno = pytest.main(self.test_args)
        sys.exit(errno)


setup(
    name='django_contactform_bootstrap',
    version=contact_form_bootstrap.VERSION,
    packages=find_packages('.'),
    include_package_data=True,
    license='BSD License',  # example license
    description='A Django Base contact form with bootstrap 3 and map.',
    long_description=README,
    url='http://www.github.com/alainivars/contact_form_bootstrap/',
    author='James Bennett, Alain Ivars',
    author_email='alainivars@highfeature.com',
    extras_require={
        'tests': tests_require,
        'dev': dev_requires,
        'prod': prod_requires,
    },
    install_requires=install_requires,
    tests_require=tests_require,
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        # Replace these appropriately if you are stuck on Python 2.
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.4',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
    cmdclass={'test': PyTest},
)
